nose_watcher package
====================

Submodules
----------

nose_watcher.nose_watcher module
--------------------------------

.. automodule:: nose_watcher.nose_watcher
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: nose_watcher
    :members:
    :undoc-members:
    :show-inheritance:
